#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = __importDefault(require("commander"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const __1 = require("..");
const types_1 = require("../types");
const packageJsonLocation = path_1.default.resolve(__dirname, '..', '..', 'package.json');
const pkg = fs_extra_1.default.readJsonSync(packageJsonLocation);
commander_1.default
    .version(pkg.version)
    .usage('<replacementFile> [options]')
    .arguments('<replacementFile>')
    .description('Replaces in files, using a JSON file containing matches and replacements.\n' +
    "The JSON file must contain an object (or array of objects), each containing a 'find' and 'replace' entry", {
    replacementFile: 'The JSON file containing matches and replacements'
})
    .option('-f, --file [file...]', 'Path or glob to a file to replace. Can be used multiple times.')
    .option('-v, --verbose', 'Turns on verbose mode')
    .parse(process.argv);
main().catch(err => {
    console.error(`ERROR: ${err}`);
    process.exit(1);
});
async function main() {
    const files = commander_1.default.file || [];
    const replacementFiles = commander_1.default.args || [];
    const verbose = commander_1.default.verbose || false;
    if (replacementFiles.length === 0) {
        throw new Error('Missing JSON replacement file. This must be the first argument. See -h for usage.');
    }
    if (replacementFiles.length > 1) {
        throw new Error('Cannot specify more than 1 JSON replacement file. See -h for usage.');
    }
    const jsonConfigFile = replacementFiles[0];
    const results = await __1.findReplace({
        files,
        jsonConfigFile,
        verbose
    });
    const totalReplaceCount = results.reduce((acc, result) => acc + result.replaceCount, 0);
    console.log(`Replaced ${chalk_1.default.bold(totalReplaceCount)} occurrences in total`);
    console.log(results.map(types_1.findReplaceResultToString).join('\n'));
}
//# sourceMappingURL=index.js.map