"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findReplace = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const globby_1 = __importDefault(require("globby"));
const find_replace_in_file_1 = require("./find-replace-in-file");
const map_concurrently_1 = require("./map-concurrently");
const replacement_1 = require("./replacement");
const DEFAULT_CONCURRENCY = 1;
async function findReplace(opts) {
    const { files, jsonConfigFile, concurrency = DEFAULT_CONCURRENCY, verbose = false } = opts;
    if (files.length === 0) {
        throw new Error('Must specify input files or globs');
    }
    const configJson = await fs_extra_1.default.readJson(jsonConfigFile);
    const config = replacement_1.parseReplacements(configJson);
    if (verbose) {
        const configStr = config.map(item => `  ${replacement_1.replacementToString(item)}`).join('\n');
        console.log(`Loaded replacements from ${chalk_1.default.green(opts.jsonConfigFile)}:\n${configStr}`);
    }
    const matchedFiles = await globby_1.default(files);
    if (verbose) {
        const filesStr = files.map(str => `  ${chalk_1.default.cyan(str)}`).join('\n');
        console.log('File globs:');
        console.log(filesStr);
        const matchedFilesStr = matchedFiles.map(str => `  ${chalk_1.default.cyan(str)}`).join('\n');
        console.log('Found these files:');
        console.log(matchedFilesStr);
    }
    return map_concurrently_1.mapConcurrently(concurrency, file => find_replace_in_file_1.findReplaceInFile(file, config, verbose), matchedFiles);
}
exports.findReplace = findReplace;
//# sourceMappingURL=index.js.map