"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findOffset = exports.computeLineOffsets = void 0;
const separator = '\n';
function computeLineOffsets(contents) {
    const lines = contents.split(separator);
    const initialState = [];
    const result = lines.reduce((acc, item, index) => {
        const lastEndOffset = acc.length === 0 ? 0 : acc[acc.length - 1].endOffset;
        const lineLength = item.length + separator.length;
        const lineOffset = {
            line: item,
            lineNumber: index + 1,
            startOffset: lastEndOffset,
            length: lineLength,
            endOffset: lastEndOffset + lineLength
        };
        return acc.concat(lineOffset);
    }, initialState);
    return result;
}
exports.computeLineOffsets = computeLineOffsets;
function findOffset(lineOffsets, offset) {
    for (let i = 0; i < lineOffsets.length; i++) {
        const lineOffset = lineOffsets[i];
        if (lineOffset.startOffset <= offset && offset < lineOffset.endOffset) {
            return {
                lineIndex: i,
                columnIndex: offset - lineOffset.startOffset
            };
        }
    }
    throw new Error(`Offset out of bounds: ${offset}`);
}
exports.findOffset = findOffset;
//# sourceMappingURL=line-offsets.js.map