"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.regexFromReplacement = exports.replacementToString = exports.parseReplacements = void 0;
const chalk_1 = __importDefault(require("chalk"));
const escape_string_regexp_1 = __importDefault(require("escape-string-regexp"));
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
function parseReplacements(input) {
    if (Array.isArray(input)) {
        return input.map(parseEntry);
    }
    return [parseEntry(input)];
}
exports.parseReplacements = parseReplacements;
function parseEntry(entry) {
    if (!entry) {
        throw new Error(`Expected entry ot be non-falsy, found '${entry}'`);
    }
    if (typeof entry !== 'object') {
        throw new Error(`Expected entry to be object, found ${typeof entry}`);
    }
    if (!('find' in entry)) {
        throw new Error(`No 'find' found in entry: ${JSON.stringify(entry)}`);
    }
    if (!('replace' in entry)) {
        throw new Error(`No 'replace' found in entry: ${JSON.stringify(entry)}`);
    }
    if (typeof entry.find !== 'string') {
        throw new Error(`Expected 'find' to be string, found ${typeof entry.find}: ${JSON.stringify(entry)}`);
    }
    if (typeof entry.replace !== 'string') {
        throw new Error(`Expected 'replace' to be string, found ${typeof entry.find}: ${JSON.stringify(entry)}`);
    }
    const ignoreCase = 'ignoreCase' in entry && entry.ignoreCase === true;
    const wholeWord = 'wholeWord' in entry && entry.wholeWord === true;
    return {
        find: entry.find,
        replace: entry.replace,
        ignoreCase,
        wholeWord
    };
}
function replacementToString(item) {
    return `${chalk_1.default.bold(item.find)} => ${chalk_1.default.bold(item.replace)}${item.wholeWord ? chalk_1.default.gray(' [wholeWord]') : ''}${item.ignoreCase ? chalk_1.default.gray(' [ignoreCase]') : ''}`;
}
exports.replacementToString = replacementToString;
function regexFromReplacement(replacement) {
    const ignoreCaseFlag = replacement.ignoreCase ? 'i' : '';
    const flags = `g${ignoreCaseFlag}`;
    const escapedFindText = escape_string_regexp_1.default(replacement.find);
    const regexText = replacement.wholeWord ? `\\b${escapedFindText}\\b` : escapedFindText;
    const regexp = new RegExp(regexText, flags);
    return regexp;
}
exports.regexFromReplacement = regexFromReplacement;
//# sourceMappingURL=replacement.js.map